@@ -1,8 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-/*
- *  Authors: Jeffrey Stedfast <fejj@ximian.com>
- *
- *  Copyright 2001-2004 Ximian, Inc. (www.ximian.com)
+/*  GMime
+ *  Copyright (C) 2000-2007 Jeffrey Stedfast
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,8 +14,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
- *
+ *  Foundation, 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 
@@ -87,7 +84,7 @@ g_mime_stream_filter_get_type (void)
 			NULL, /* class_finalize */
 			NULL, /* class_data */
 			sizeof (GMimeStreamFilter),
-			16,   /* n_preallocs */
+			0,    /* n_preallocs */
 			(GInstanceInitFunc) g_mime_stream_filter_init,
 		};
 		
@@ -237,7 +234,7 @@ stream_write (GMimeStream *stream, const char *buf, size_t n)
 		f = f->next;
 	}
 	
-	if (g_mime_stream_write (filter->source, buffer, n) != n)
+	if (g_mime_stream_write (filter->source, buffer, n) == -1)
 		return -1;
 	
 	/* return original input len because that's what our caller expects */
@@ -309,6 +306,9 @@ stream_reset (GMimeStream *stream)
 	struct _GMimeStreamFilterPrivate *priv = filter->priv;
 	struct _filter *f;
 	
+	if (g_mime_stream_reset (filter->source) == -1)
+		return -1;
+	
 	priv->filteredlen = 0;
 	priv->flushed = FALSE;
 	
@@ -319,7 +319,7 @@ stream_reset (GMimeStream *stream)
 		f = f->next;
 	}
 	
-	return g_mime_stream_reset (filter->source);
+	return 0;
 }
 
 static off_t
@@ -346,7 +346,7 @@ stream_substream (GMimeStream *stream, off_t start, off_t end)
 	GMimeStreamFilter *filter = (GMimeStreamFilter *) stream;
 	GMimeStreamFilter *sub;
 	
-	sub = g_object_new (GMIME_TYPE_STREAM_FILTER, NULL, NULL);
+	sub = g_object_new (GMIME_TYPE_STREAM_FILTER, NULL);
 	sub->source = filter->source;
 	g_object_ref (sub->source);
 	
@@ -374,9 +374,7 @@ stream_substream (GMimeStream *stream, off_t start, off_t end)
 		sub->priv->filterid = filter->priv->filterid;
 	}
 	
-	g_mime_stream_construct (GMIME_STREAM (filter),
-				 sub->source->bound_start,
-				 sub->source->bound_end);
+	g_mime_stream_construct (GMIME_STREAM (filter), start, end);
 	
 	return GMIME_STREAM (sub);
 }
@@ -398,7 +396,7 @@ g_mime_stream_filter_new_with_stream (GMimeStream *stream)
 	
 	g_return_val_if_fail (GMIME_IS_STREAM (stream), NULL);
 	
-	filter = g_object_new (GMIME_TYPE_STREAM_FILTER, NULL, NULL);
+	filter = g_object_new (GMIME_TYPE_STREAM_FILTER, NULL);
 	filter->source = stream;
 	g_object_ref (stream);
 	
